summaryrefslogtreecommitdiff
path: root/include/svx/sdr
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-12-15 10:31:06 +0200
committerNoel Grandin <noel@peralex.com>2015-12-15 10:42:52 +0200
commit4463da0488099b52959544923407b15d73d3e172 (patch)
treec0fd9ada0bfdf2d3925fc1c94bac3782d332ef5a /include/svx/sdr
parent00ea9e5e4ef2f20353c881ec5844ed3862897239 (diff)
use vector as container for Primitive3DReference
rather than uno::Sequence, since we modify this container a lot and uno::Sequence is expensive to update Change-Id: Id5bc5171cbc4b90b243e6dda6d572f21b3bdf00d
Diffstat (limited to 'include/svx/sdr')
-rw-r--r--include/svx/sdr/contact/viewcontactofe3d.hxx16
-rw-r--r--include/svx/sdr/contact/viewcontactofe3dscene.hxx2
2 files changed, 9 insertions, 9 deletions
diff --git a/include/svx/sdr/contact/viewcontactofe3dscene.hxx b/include/svx/sdr/contact/viewcontactofe3dscene.hxx
index ce9e85113963..a802db8384a5 100644
--- a/include/svx/sdr/contact/viewcontactofe3dscene.hxx
+++ b/include/svx/sdr/contact/viewcontactofe3dscene.hxx
@@ -70,7 +70,7 @@ public:
// helpers to get the sequence of all contained 3D primitives and its range,
// regardless of layer or visibility constraints and using a neutral ViewInformation3D
- drawinglayer::primitive3d::Primitive3DSequence getAllPrimitive3DSequence() const;
+ drawinglayer::primitive3d::Primitive3DContainer getAllPrimitive3DContainer() const;
basegfx::B3DRange getAllContentRange3D() const;
protected:
diff --git a/include/svx/sdr/contact/viewcontactofe3d.hxx b/include/svx/sdr/contact/viewcontactofe3d.hxx
index eed59dded3d6..33d6c037693c 100644
--- a/include/svx/sdr/contact/viewcontactofe3d.hxx
+++ b/include/svx/sdr/contact/viewcontactofe3d.hxx
@@ -56,22 +56,22 @@ public:
}
// public helpers
- drawinglayer::primitive2d::Primitive2DContainer impCreateWithGivenPrimitive3DSequence(
- const drawinglayer::primitive3d::Primitive3DSequence& rxContent3D) const;
+ drawinglayer::primitive2d::Primitive2DContainer impCreateWithGivenPrimitive3DContainer(
+ const drawinglayer::primitive3d::Primitive3DContainer& rxContent3D) const;
// primitive stuff
protected:
// Primitive3DSequence of the ViewContact. This contains all necessary information
// for the graphical visualisation and needs to be supported by all 3D VCs which
// can be visualized. It does NOT contain the object transformation to be able to
// buffer for all possible usages
- drawinglayer::primitive3d::Primitive3DSequence mxViewIndependentPrimitive3DSequence;
+ drawinglayer::primitive3d::Primitive3DContainer mxViewIndependentPrimitive3DContainer;
// This method is responsible for creating the graphical visualisation data which is
- // stored in mxViewIndependentPrimitive3DSequence, but without object transformation
- virtual drawinglayer::primitive3d::Primitive3DSequence createViewIndependentPrimitive3DSequence() const = 0;
+ // stored in mxViewIndependentPrimitive3DContainer, but without object transformation
+ virtual drawinglayer::primitive3d::Primitive3DContainer createViewIndependentPrimitive3DContainer() const = 0;
// This method is responsible for creating the graphical visualisation data derived ONLY from
// the model data. The default implementation will try to create a 3D to 2D embedding (will work
@@ -81,13 +81,13 @@ protected:
public:
// access to the local primitive without the object's local 3D transform. This is e.g. needed
// to get the not-yet transformed BoundVolume for e.g. interactions
- drawinglayer::primitive3d::Primitive3DSequence getVIP3DSWithoutObjectTransform() const;
+ drawinglayer::primitive3d::Primitive3DContainer getVIP3DSWithoutObjectTransform() const;
// access to the local primitive. This will ensure that the list is
// current in comparing the local list content with a fresh created incarnation. It will
// use getVIP3DSWithoutObjectTransform and embed to 3d transform primitive when object's
// local 3d transform is used
- drawinglayer::primitive3d::Primitive3DSequence getViewIndependentPrimitive3DSequence() const;
+ drawinglayer::primitive3d::Primitive3DContainer getViewIndependentPrimitive3DContainer() const;
};
}}
@@ -56,22 +56,22 @@ public:
// primitive stuff
protected:
- // Primitive3DSequence of the ViewContact. This contains all necessary information
+ // Primitive3DContainer of the ViewContact. This contains all necessary information
// for the graphical visualisation and needs to be supported by all 3D VCs which
// can be visualized. It does NOT contain the object transformation to be able to